# Generated by Django 5.1.1 on 2024-09-24 17:28

from django.apps.registry import Apps
from django.db import migrations
from django.db.backends.base.schema import BaseDatabaseSchemaEditor

from sentry.new_migrations.migrations import CheckedMigration
from sentry.utils.query import RangeQuerySetWrapperWithProgressBarApprox


class GroupStatus:
    PENDING_MERGE = 5


# End copy


def fix_substatus_for_pending_merge(apps: Apps, schema_editor: BaseDatabaseSchemaEditor) -> None:
    Group = apps.get_model("sentry", "Group")

    for group in RangeQuerySetWrapperWithProgressBarApprox(
        Group.objects.filter(status=GroupStatus.PENDING_MERGE, substatus__isnull=False)
    ):
        group.substatus = None
        group.save(update_fields=["substatus"])


class Migration(CheckedMigration):
    # This flag is used to mark that a migration shouldn't be automatically run in production.
    # This should only be used for operations where it's safe to run the migration after your
    # code has deployed. So this should not be used for most operations that alter the schema
    # of a table.
    # Here are some things that make sense to mark as post deployment:
    # - Large data migrations. Typically we want these to be run manually so that they can be
    #   monitored and not block the deploy for a long period of time while they run.
    # - Adding indexes to large tables. Since this can take a long time, we'd generally prefer to
    #   run this outside deployments so that we don't block them. Note that while adding an index
    #   is a schema change, it's completely safe to run the operation after the code has deployed.
    # Once deployed, run these manually via: https://develop.sentry.dev/database-migrations/#migration-deployment

    is_post_deployment = True

    dependencies = [
        ("sentry", "0765_add_org_to_api_auth"),
    ]

    operations = [
        migrations.RunPython(
            fix_substatus_for_pending_merge,
            migrations.RunPython.noop,
            hints={"tables": ["sentry_groupedmessage", "sentry_grouphistory"]},
        ),
    ]
