# Generated by Django 5.1.1 on 2024-10-24 19:51

from django.apps.registry import Apps
from django.db import migrations
from django.db.backends.base.schema import BaseDatabaseSchemaEditor

from sentry.new_migrations.migrations import CheckedMigration
from sentry.utils.query import RangeQuerySetWrapperWithProgressBarApprox

BATCH_SIZE = 100


class GroupStatus:
    RESOLVED = 1
    IGNORED = 2


def remove_groups_from_group_inbox(apps: Apps, schema_editor: BaseDatabaseSchemaEditor) -> None:
    GroupInbox = apps.get_model("sentry", "GroupInbox")

    group_ids_to_delete = []
    for group_inbox in RangeQuerySetWrapperWithProgressBarApprox(
        GroupInbox.objects.select_related("group").all()
    ):
        if (
            group_inbox.group.status == GroupStatus.RESOLVED
            or group_inbox.group.status == GroupStatus.IGNORED
        ):
            group_ids_to_delete.append(group_inbox.group_id)

        if len(group_ids_to_delete) >= BATCH_SIZE:
            GroupInbox.objects.filter(group_id__in=group_ids_to_delete).delete()
            group_ids_to_delete = []

    if group_ids_to_delete:
        GroupInbox.objects.filter(group_id__in=group_ids_to_delete).delete()


class Migration(CheckedMigration):
    # This flag is used to mark that a migration shouldn't be automatically run in production.
    # This should only be used for operations where it's safe to run the migration after your
    # code has deployed. So this should not be used for most operations that alter the schema
    # of a table.
    # Here are some things that make sense to mark as post deployment:
    # - Large data migrations. Typically we want these to be run manually so that they can be
    #   monitored and not block the deploy for a long period of time while they run.
    # - Adding indexes to large tables. Since this can take a long time, we'd generally prefer to
    #   run this outside deployments so that we don't block them. Note that while adding an index
    #   is a schema change, it's completely safe to run the operation after the code has deployed.
    # Once deployed, run these manually via: https://develop.sentry.dev/database-migrations/#migration-deployment

    is_post_deployment = True

    dependencies = [
        ("sentry", "0778_userreport_comments_max_length"),
    ]

    operations = [
        migrations.RunPython(
            remove_groups_from_group_inbox,
            migrations.RunPython.noop,
            hints={"tables": ["sentry_groupinbox"]},
        ),
    ]
