# Generated by Django 5.0.8 on 2024-08-13 23:43

from django.db import migrations
from django.db.backends.base.schema import BaseDatabaseSchemaEditor
from django.db.migrations.state import StateApps

from sentry.new_migrations.migrations import CheckedMigration
from sentry.utils.query import RangeQuerySetWrapperWithProgressBar

# ProjectUptimeSubscriptionMode.AUTO_DETECTED_ACTIVE
AUTO_DETECTED_ACTIVE = 3
# UptimeSubscription.Status.CREATING
CREATING_STATUS = 1


def update_auto_detected_active_interval_seconds(
    apps: StateApps, schema_editor: BaseDatabaseSchemaEditor
) -> None:
    ProjectUptimeSubscription = apps.get_model("uptime", "ProjectUptimeSubscription")

    uptime_proj_subs = ProjectUptimeSubscription.objects.all().select_related("uptime_subscription")

    for uptime_proj_sub in RangeQuerySetWrapperWithProgressBar(uptime_proj_subs):
        uptime_sub = uptime_proj_sub.uptime_subscription
        if uptime_proj_sub.mode == AUTO_DETECTED_ACTIVE and uptime_sub.interval_seconds == 300:
            uptime_sub.interval_seconds = 60
            uptime_sub.status = CREATING_STATUS
            uptime_sub.save(update_fields=["interval_seconds", "status"])


class Migration(CheckedMigration):
    # This flag is used to mark that a migration shouldn't be automatically run in production.
    # This should only be used for operations where it's safe to run the migration after your
    # code has deployed. So this should not be used for most operations that alter the schema
    # of a table.
    # Here are some things that make sense to mark as post deployment:
    # - Large data migrations. Typically we want these to be run manually so that they can be
    #   monitored and not block the deploy for a long period of time while they run.
    # - Adding indexes to large tables. Since this can take a long time, we'd generally prefer to
    #   run this outside deployments so that we don't block them. Note that while adding an index
    #   is a schema change, it's completely safe to run the operation after the code has deployed.
    # Once deployed, run these manually via: https://develop.sentry.dev/database-migrations/#migration-deployment

    is_post_deployment = True

    dependencies = [
        ("uptime", "0006_projectuptimesubscription_name_owner"),
    ]

    operations = [
        migrations.RunPython(
            update_auto_detected_active_interval_seconds,
            migrations.RunPython.noop,
            hints={"tables": ["uptime_projectuptimesubscription", "uptime_uptimesubscription"]},
        ),
    ]
